@@ -16,6 +16,7 @@
 # May 23, 2012 Sanford Weisberg sandy@umn.edu
 # June 1, 2012:  changed from class c("Boot", "boot") to just class "boot"
 # 2012-12-10 replaced .GlobalEnv with .carEnv to avoid warnings
+# 2013-07-08 changed .carEnv to car:::.carEnv so 'boot' could find the environment
 
 Boot <- function(object, f, labels, R=999, method){UseMethod("Boot")}
 
@@ -27,8 +28,8 @@ Boot.default <- function(object, f=coef, labels=names(coef(object)),
   method <- match.arg(method)
   if(method=="case") {
      boot.f <- function(data, indices, .fn) {
-      assign(".boot.indices", indices, envir=.carEnv)
-      mod <- update(object, subset=get(".boot.indices", envir=.carEnv))
+      assign(".boot.indices", indices, envir=car:::.carEnv)
+      mod <- update(object, subset=get(".boot.indices", envir=car:::.carEnv))
       if(mod$qr$rank != object$qr$rank){
             out <- .fn(object)
             out <- rep(NA, length(out)) } else  {out <- .fn(mod)}
@@ -46,8 +47,8 @@ Boot.default <- function(object, f=coef, labels=names(coef(object)),
             attr(pad, "class") <- "exclude" 
             val <- naresid(pad, val)
             }
-      assign(".y.boot", val, envir=.carEnv)
-      mod <- update(object, get(".y.boot", envir=.carEnv) ~ .)
+      assign(".y.boot", val, envir=car:::.carEnv)
+      mod <- update(object, get(".y.boot", envir=car:::.carEnv) ~ .)
       if(mod$qr$rank != object$qr$rank){
             out <- .fn(object)
             out <- rep(NA, length(out)) } else  {out <- .fn(mod)}
@@ -56,8 +57,10 @@ Boot.default <- function(object, f=coef, labels=names(coef(object)),
   } 
   b <- boot(data.frame(update(object, model=TRUE)$model), boot.f, R, .fn=f)
   colnames(b$t) <- labels
-  if(exists(".y.boot", envir=.carEnv)) remove(".y.boot", envir=.carEnv)
-  if(exists(".boot.indices", envir=.carEnv)) remove(".boot.indices", envir=.carEnv)
+  if(exists(".y.boot", envir=car:::.carEnv))
+     remove(".y.boot", envir=car:::.carEnv)
+  if(exists(".boot.indices", envir=car:::.carEnv))
+     remove(".boot.indices", envir=car:::.carEnv)
   b
   }
   
@@ -85,8 +88,8 @@ Boot.nls <- function(object, f=coef, labels=names(coef(object)),
   opt<-options(show.error.messages = FALSE)
   if(method=="case") {
      boot.f <- function(data, indices, .fn) {
-         assign(".boot.indices", indices, envir=.carEnv)
-         mod <- try(update(object, subset=get(".boot.indices", envir=.carEnv),
+         assign(".boot.indices", indices, envir=car:::.carEnv)
+         mod <- try(update(object, subset=get(".boot.indices", envir=car:::.carEnv),
                  start=coef(object)))
          if(class(mod) == "try-error"){
             out <- .fn(object)
@@ -103,7 +106,7 @@ Boot.nls <- function(object, f=coef, labels=names(coef(object)),
             attr(pad, "class") <- "exclude"
             val <- naresid(pad, val)
             }
-      assign(".y.boot", val, envir=.carEnv)
+      assign(".y.boot", val, envir=car:::.carEnv)
       mod <- try(update(object, get(".y.boot", envir-.carEnv) ~ .,
              start=coef(object)))
       if(class(mod) == "try-error"){
@@ -114,8 +117,10 @@ Boot.nls <- function(object, f=coef, labels=names(coef(object)),
   }
   b <- boot(data.frame(update(object, model=TRUE)$model), boot.f, R, .fn=f)
   colnames(b$t) <- labels
-  if(exists(".y.boot", envir=.carEnv)) remove(".y.boot", envir=.carEnv)
-  if(exists(".boot.indices", envir=.carEnv)) remove(".boot.indices", envir=.carEnv)
+  if(exists(".y.boot", envir=car:::.carEnv))
+     remove(".y.boot", envir=car:::.carEnv)
+  if(exists(".boot.indices", envir=car:::.carEnv))
+     remove(".boot.indices", envir=car:::.carEnv)
   options(opt)
   d <- dim(na.omit(b$t))[1]
   if(d != R)
